### R code from vignette source 'networkDynamic.Rnw'

###################################################
### code chunk number 1: foo
###################################################
options(keep.source = TRUE, width = 60)
foo <- packageDescription("networkDynamic")


###################################################
### code chunk number 2: trivial_triangle
###################################################
library(networkDynamic)          # load the dynamic extensions
triangle <- network.initialize(3)  # create a toy network
add.edge(triangle,1,2)    # add an edge between vertices 1 and 2
add.edge(triangle,2,3)               # add a more edges
activate.edges(triangle,at=1) # turn on all edges at time 1 only
activate.edges(triangle,onset=2, terminus=3, 
               e=get.edgeIDs(triangle,v=1,alter=2))
add.edges.active(triangle,onset=4, length=2,tail=3,head=1)
class(triangle)


###################################################
### code chunk number 3: triangle_degree
###################################################
degree<-function(x){as.vector(rowSums(as.matrix(x))
             +colSums(as.matrix(x)))} # handmade degree function
degree(triangle)  # degree of each vertex, ignoring time
degree(network.extract(triangle,at=0)) 
degree(network.extract(triangle,at=1)) # just look at t=1
degree(network.extract(triangle,at=2))
degree(network.extract(triangle,at=5))
degree(network.extract(triangle,at=10))


###################################################
### code chunk number 4: fig1
###################################################
par(mfrow=c(2,2))   #show multiple plots
plot(triangle,main='ignoring dynamics',displaylabels=T)  
plot(network.extract(
  triangle,onset=1,terminus=2),main='at time 1',displaylabels=T)
plot(network.extract(
  triangle,onset=2,terminus=3),main='at time 2',displaylabels=T)
plot(network.extract(
  triangle,onset=5,terminus=6),main='at time 5',displaylabels=T)


###################################################
### code chunk number 5: fig1
###################################################
par(mfrow=c(2,2))   #show multiple plots
plot(triangle,main='ignoring dynamics',displaylabels=T)  
plot(network.extract(
  triangle,onset=1,terminus=2),main='at time 1',displaylabels=T)
plot(network.extract(
  triangle,onset=2,terminus=3),main='at time 2',displaylabels=T)
plot(network.extract(
  triangle,onset=5,terminus=6),main='at time 5',displaylabels=T)


###################################################
### code chunk number 6: triangle_vert_activate
###################################################
activate.vertices(triangle,onset=1,terminus=5,v=1) 
activate.vertices(triangle,onset=1,terminus=10,v=2)
activate.vertices(triangle,onset=4,terminus=10,v=3)
network.size(network.extract(triangle,at=1)) # how big is it?
network.size(network.extract(triangle,at=4))
network.size(network.extract(triangle,at=5))


###################################################
### code chunk number 7: triangle_check
###################################################
network.dynamic.check(triangle)


###################################################
### code chunk number 8: triangle_deactivate
###################################################
deactivate.edges(triangle,onset=1,terminus=4,
          e=get.edgeIDs(triangle,v=3,neighborhood="combined"))
network.dynamic.check(triangle)


###################################################
### code chunk number 9: triangle_get_times
###################################################
get.vertex.activity(triangle) # vertex spells
get.edge.activity(triangle) # edge spells


###################################################
### code chunk number 10: discrete_vs_cont
###################################################

disc <- network.initialize(2)
disc[1,2]<-1
activate.edges(disc,onset=4,terminus=6) # terminus = t+1
is.active(disc,at=4,e=1)
is.active(disc,at=5,e=1)
is.active(disc,at=6,e=1)

cont <- network.initialize(2)
cont[1,2]<-1
activate.edges(cont,onset=4,terminus=5)
is.active(cont,at=4,e=1)
is.active(cont,at=5,e=1)

cont <- network.initialize(2)
cont[1,2]<-1
activate.edges(cont,onset=3.0,terminus=5.0001)
is.active(cont,at=4,e=1)
is.active(cont,at=5,e=1)

point <- network.initialize(2) # continuous waves
point[1,2]<-1
activate.edges(point,at=4)
activate.edges(point,at=5)
is.active(point,at=4,e=1)
is.active(point,at=4.5,e=1) # this doesn't makes sense
is.active(point,at=5,e=1)


###################################################
### code chunk number 11: is_active
###################################################
is.active(triangle, onset=1, length=1,v=2:3)
is.active(triangle, onset=1, length=1,e=get.edgeIDs(triangle,v=1))


###################################################
### code chunk number 12: get_active
###################################################
get.edgeIDs.active(triangle, onset=2, length=1,v=1)
get.neighborhood.active(triangle, onset=2, length=1,v=1)
is.adjacent.active(triangle,vi=1,vj=2,onset=2,length=1)


###################################################
### code chunk number 13: get_change_times
###################################################
get.change.times(triangle)
get.change.times(triangle,vertex.activity=FALSE)
get.change.times(triangle,edge.activity=FALSE)


###################################################
### code chunk number 14: size_and_edgecount
###################################################
network.size.active(triangle,onset=2,terminus=3)
network.edgecount.active(triangle,at=5)


###################################################
### code chunk number 15: delete_times
###################################################
delete.edge.activity(triangle)
delete.vertex.activity(triangle)
get.change.times(triangle)


###################################################
### code chunk number 16: any_all
###################################################
query <- network.initialize(2)
query[1,2] <-1
activate.edges(query, onset=1, terminus=2)
is.active(query,onset=1,terminus=2,e=1)
is.active(query,onset=1,terminus=3,rule='all',e=1)
is.active(query,onset=1,terminus=3,rule='any',e=1)


###################################################
### code chunk number 17: newcomb (eval = FALSE)
###################################################
## require(networkDynamic)
## data(newcomb)             # load the data
## names(newcomb)            # its some kind of named list object
## length(newcomb)   # how many networks?
## is.network(newcomb[[1]]) # is it really a network?
## as.sociomatrix(newcomb[[1]]) # peek at sociomatrix       
## newcombDyn <- as.networkDynamic(newcomb)  # make dynamic  
## # check that it is the same
## identical(as.sociomatrix(newcomb[[1]]),
##           as.sociomatrix(network.extract(newcombDyn,onset=0,terminus=1)))


###################################################
### code chunk number 18: file_spells (eval = FALSE)
###################################################
## spellData <-read.table(system.file('extdata/cls33_10_16_96.son', 
##             package='networkDynamic'),skip=22,header=T)
## spellData[1:5,] # peek
## classDyn <- as.networkDynamic(spellData[,c(3:4,1:2)]) #just grab 4 cols


###################################################
### code chunk number 19: newcomb (eval = FALSE)
###################################################
## newcombEdgeSpells<-as.data.frame(newcombDyn)
## dim(newcombEdgeSpells) # how big is it?
## newcombEdgeSpells[1:5,] # peek at the beginning


###################################################
### code chunk number 20: classroom_binning (eval = FALSE)
###################################################
## startTimes <-seq(from=0,to=40,by=5) # make a list of times 
## classNets <- lapply(startTimes, function(t){ 
##   network.extract(classDyn,onset=t,terminus=t+5)})
## classMats <- lapply(classNets,as.sociomatrix) # make into matrices
## classDensity <- sapply(classNets, network.density) 
## plot(classDensity,type='l',xlab='network slice #',ylab='density')


###################################################
### code chunk number 21: windsurfers
###################################################
data(windsurfers)    # let's go to the beach!
days <- c(1,7,14,21)
sapply(days,function(t){ # how many people in net each week?
  network.size.active(windsurfers,onset=t,length=7)})


###################################################
### code chunk number 22: classroom
###################################################
data(McFarland_cls33_10_16_96) # goin' back to school



###################################################
### code chunk number 23: fig2
###################################################
par(mfrow=c(2,2))   # show multiple plots
plot(network.extract(
  cls33_10_16_96,onset=0,length=40,rule="any"),
  main='entire 40 min class period',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=5,rule="any"),
  main='a 5 min chunk',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=2.5,rule="any"),
  main='a 2.5 min chunk',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=.1,rule="any"),
  main='a single conversation turn',displaylabels=T)


###################################################
### code chunk number 24: fig2
###################################################
par(mfrow=c(2,2))   # show multiple plots
plot(network.extract(
  cls33_10_16_96,onset=0,length=40,rule="any"),
  main='entire 40 min class period',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=5,rule="any"),
  main='a 5 min chunk',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=2.5,rule="any"),
  main='a 2.5 min chunk',displaylabels=T)
plot(network.extract(
  cls33_10_16_96,onset=0,length=.1,rule="any"),
  main='a single conversation turn',displaylabels=T)


###################################################
### code chunk number 25: package_listing
###################################################
cat(ls("package:networkDynamic"),sep="\n")


